==> u61-0.1.0.tar.gz: u61-0.1.0/src/debug.h <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   debug.h
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: utilities to log messages and debug the program
 */

#ifndef INC_U61_DEBUG
#define INC_U61_DEBUG

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include <ClanLib/core.h>

/*---------------------------------------------------------------------------
 classes
 ---------------------------------------------------------------------------*/

class U61_Debug
{
public:
    static void log_console(const ostream &o,bool always=false);
    static void log_file(const ostream &o,bool always=false);
    static bool console_state;
    static bool file_state;
    static void set_file(char *name);
protected:
    static char *file_name;
};

#endif

==> u61-0.3.2.tar.gz: u61-0.3.2/src/debug.h <==
/****************************************************************************
 *                                                                          *
 * U U    6   1            U U   FFF  O   O  TTT                            *
 * U U   6   11   b        U U   F   O O O O  T                             *
 * U U - 66   1   bb  y y  U U - FF  O O O O  T                             *
 * U U   6 6  1   b b  y   U U   F   O O O O  T                             *
 *  U     6   1   bb   y    U    F    O   O   T                             *
 *                                                                          *
 * U61 is another block based game                                          *
 * Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   *
 *                                                                          *
 * This program is free software; you can redistribute it and/or            *
 * modify it under the terms of the GNU General Public License              *
 * as published by the Free Software Foundation; either version 2           *
 * of the License, or (at your option) any later version.                   *
 *                                                                          *
 * This program is distributed in the hope that it will be useful,          *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of           *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            *
 * GNU General Public License for more details.                             *
 *                                                                          *
 * You should have received a copy of the GNU General Public License        *
 * along with this program; if not, write to the Free Software              *
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA*
 *                                                                          *
 * This project is also available on SourceForge  (http://sourceforge.net)  *
 ****************************************************************************/

/*
 * file name:   debug.h
 * author:      U-Foot (ufoot@ufoot.org / www.ufoot.org)
 * description: utilities to log messages and debug the program
 */

#ifndef INC_U61_DEBUG
#define INC_U61_DEBUG

/*---------------------------------------------------------------------------
 includes
 ---------------------------------------------------------------------------*/

#include <strstream.h>
#include <fstream.h>

#include <ClanLib/core.h>

/*---------------------------------------------------------------------------
 macros
 ---------------------------------------------------------------------------*/

#define U61_LOG_ERROR(M) {ostrstream s;s<<M;U61_Debug::log_error(s);}
#define U61_LOG_WARNING(M) {ostrstream s;s<<M;U61_Debug::log_warning(s);}
#define U61_LOG_MESSAGE(M) {ostrstream s;s<<M;U61_Debug::log_message(s);}
#ifdef DEBUG
#define U61_LOG_DEBUG(M) {ostrstream s;s<<M;U61_Debug::log_debug(s,__FILE__,__LINE__);}
#else
#define U61_LOG_DEBUG(M)
#endif

/*---------------------------------------------------------------------------
 classes
 ---------------------------------------------------------------------------*/

class U61_Debug
{
public:
    static void init();
    static void deinit();
    static void flush();    

    static void log_error(ostrstream &s);
    static void log_warning(ostrstream &s);
    static void log_message(ostrstream &s);
    static void log_debug(ostrstream &s,char *file,int line);
protected:

};

#endif
